==> huaweicloudsdkdrs-3.0.50-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/batch_validate_clusters_connections_response.py <==
# coding: utf-8

import pprint
import re

import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class BatchValidateClustersConnectionsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'results': 'list[CheckJobResp]',
        'count': 'int'
    }

    attribute_map = {
        'results': 'results',
        'count': 'count'
    }

    def __init__(self, results=None, count=None):
        """BatchValidateClustersConnectionsResponse - a model defined in huaweicloud sdk"""
        
        super(BatchValidateClustersConnectionsResponse, self).__init__()

        self._results = None
        self._count = None
        self.discriminator = None

        if results is not None:
            self.results = results
        if count is not None:
            self.count = count

    @property
    def results(self):
        """Gets the results of this BatchValidateClustersConnectionsResponse.

        批量测试连接响应体集合。

        :return: The results of this BatchValidateClustersConnectionsResponse.
        :rtype: list[CheckJobResp]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchValidateClustersConnectionsResponse.

        批量测试连接响应体集合。

        :param results: The results of this BatchValidateClustersConnectionsResponse.
        :type: list[CheckJobResp]
        """
        self._results = results

    @property
    def count(self):
        """Gets the count of this BatchValidateClustersConnectionsResponse.

        总记录数。

        :return: The count of this BatchValidateClustersConnectionsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this BatchValidateClustersConnectionsResponse.

        总记录数。

        :param count: The count of this BatchValidateClustersConnectionsResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchValidateClustersConnectionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdrs-3.0.52-py2.py3-none-any.whl: huaweicloudsdkdrs/v3/model/batch_validate_clusters_connections_response.py <==
# coding: utf-8

import re
import six


from huaweicloudsdkcore.sdk_response import SdkResponse


class BatchValidateClustersConnectionsResponse(SdkResponse):


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'results': 'list[CheckJobResp]',
        'count': 'int'
    }

    attribute_map = {
        'results': 'results',
        'count': 'count'
    }

    def __init__(self, results=None, count=None):
        """BatchValidateClustersConnectionsResponse - a model defined in huaweicloud sdk"""
        
        super(BatchValidateClustersConnectionsResponse, self).__init__()

        self._results = None
        self._count = None
        self.discriminator = None

        if results is not None:
            self.results = results
        if count is not None:
            self.count = count

    @property
    def results(self):
        """Gets the results of this BatchValidateClustersConnectionsResponse.

        批量测试连接响应体集合。

        :return: The results of this BatchValidateClustersConnectionsResponse.
        :rtype: list[CheckJobResp]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this BatchValidateClustersConnectionsResponse.

        批量测试连接响应体集合。

        :param results: The results of this BatchValidateClustersConnectionsResponse.
        :type: list[CheckJobResp]
        """
        self._results = results

    @property
    def count(self):
        """Gets the count of this BatchValidateClustersConnectionsResponse.

        总记录数。

        :return: The count of this BatchValidateClustersConnectionsResponse.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this BatchValidateClustersConnectionsResponse.

        总记录数。

        :param count: The count of this BatchValidateClustersConnectionsResponse.
        :type: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        import simplejson as json
        return json.dumps(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchValidateClustersConnectionsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
